package com.fs.delivery.mapper;

import java.util.List;
import com.fs.delivery.domain.CtArticle;

/**
 * 文章Mapper接口
 * 
 * @author fs
 * @date 2026-01-20
 */
public interface CtArticleMapper 
{
    /**
     * 查询文章
     * 
     * @param id 文章主键
     * @return 文章
     */
    public CtArticle selectCtArticleById(Long id);

    /**
     * 查询文章列表
     * 
     * @param ctArticle 文章
     * @return 文章集合
     */
    public List<CtArticle> selectCtArticleList(CtArticle ctArticle);

    /**
     * 新增文章
     * 
     * @param ctArticle 文章
     * @return 结果
     */
    public int insertCtArticle(CtArticle ctArticle);

    /**
     * 修改文章
     * 
     * @param ctArticle 文章
     * @return 结果
     */
    public int updateCtArticle(CtArticle ctArticle);

    /**
     * 删除文章
     * 
     * @param id 文章主键
     * @return 结果
     */
    public int deleteCtArticleById(Long id);

    /**
     * 批量删除文章
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteCtArticleByIds(Long[] ids);
}
